@@ -3,9 +3,7 @@ from aiohttp_requests import requests
 from kumihotools import toDomain
 import os
 
-foxhousePath = '/var/rel8ed.to/MQproject/foxhouse/'
-
-async def get_sites(sem,url): 
+async def get_sites(sem,url,foxhousePath): 
     async with sem:            
         print(url)
         domain = toDomain(url)
@@ -21,11 +19,13 @@ async def get_sites(sem,url):
             print(e)
         os.chmod(filepath,0o666)
 
-async def scrapeurls(urls, ):
+async def scrapeurls(urls, foxhousePath='websites_foxhouse'):
+    if not os.path.exists(foxhousePath):
+        os.mkdir(foxhousePath)
     tasks = []
     sem = asyncio.Semaphore(50)
     for url in urls:
-        tasks.append(asyncio.create_task(get_sites(sem,url)))
+        tasks.append(asyncio.create_task(get_sites(sem,url,foxhousePath)))
     await asyncio.gather(*tasks)
 
 if __name__ == "__main__":
